@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: free
 version: 4.12.4
-id: free-4.12.4-6ceee3b0778288ec7c5c8e8d64937985
-key: free_JtYkRgqd7lPA2FmykZrbfK
+id: free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
+key: free_ErZWHf7TcDBDd5UDoaj0YZ
 license: BSD3
 copyright: Copyright (C) 2008-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -45,18 +45,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/free-4.12.4
-hs-libraries: HSfree-4.12.4-JtYkRgqd7lPA2FmykZrbfK
+hs-libraries: HSfree-4.12.4-ErZWHf7TcDBDd5UDoaj0YZ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    bifunctors-5.2.1-f15ad2d16f9be29f17cf3cf758fe7ba6
-    comonad-5-530ea4e1d08a0115920b946124e760ac
+    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
+    comonad-5-a91321d086a2de4a04a44d60c347669e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    distributive-0.5.0.2-17a8848c95a42a5c612669379433d996
+    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     prelude-extras-0.4.0.3-1ebda3e30d44e52e3bbcd33027a32ddc
-    profunctors-5.2-1b9f80ec12ba976fbd92d616f7b33d0d
-    semigroupoids-5.0.1-fafa53fc1a76ec617ee4419105d11368
+    profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
+    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
